@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef CONFIG_DATA_H
@@ -24,6 +24,7 @@
 #include <glib.h>
 #include <libical/ical.h>
 #include <gconf/gconf-client.h>
+#include <libedataserver/e-source-list.h>
 
 GConfClient  *config_data_get_conf_client (void);
 
@@ -34,5 +35,7 @@ void          config_data_set_last_notification_time (time_t t);
 time_t        config_data_get_last_notification_time (void);
 void          config_data_save_blessed_program (const char *program);
 gboolean      config_data_is_blessed_program (const char *program);
+ESourceList  *config_data_get_calendars (const char *);
+void	      config_data_replace_string_list (const char *, const char *, const char *);
 
 #endif
