@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -25,6 +25,7 @@
 #define _EM_FOLDER_VIEW_H
 
 #include <gtk/gtkvbox.h>
+#include <gtk/gtkprintoperation.h>
 #include "mail/em-popup.h"
 
 #ifdef __cplusplus
@@ -53,7 +54,8 @@ enum {
 	EM_FOLDER_VIEW_SELECT_DISPLAY = EM_POPUP_SELECT_LAST<<5,
 	EM_FOLDER_VIEW_SELECT_SELECTION = EM_POPUP_SELECT_LAST<<6,
 	EM_FOLDER_VIEW_SELECT_NOSELECTION = EM_POPUP_SELECT_LAST<<7,
-	EM_FOLDER_VIEW_SELECT_LAST = EM_POPUP_SELECT_LAST<<8,
+	EM_FOLDER_VIEW_PREVIEW_PRESENT = EM_POPUP_SELECT_LAST<<8,
+	EM_FOLDER_VIEW_SELECT_LAST = EM_POPUP_SELECT_LAST<<9,
 };
 
 struct _EMFolderViewEnable {
@@ -88,21 +90,21 @@ struct _EMFolderView {
 	struct _BonoboUIComponent *uic;	/* if we're active, this will be set */
 	GSList *enable_map;	/* bonobo menu enable map, entries are 0-terminated EMFolderViewEnable arryas
 				   TODO: should this be on class? */
-	
+
 	int mark_seen_timeout;	/* local copy of gconf stuff */
-	int mark_seen:1;
-	int preview_active:1;	/* is preview being used */
-	int statusbar_active:1; /* should we manage the statusbar messages ourselves? */
-	int hide_deleted:1;
-	int list_active:1;	/* we actually showing the list? */
+	guint mark_seen:1;
+	guint preview_active:1;	/* is preview being used */
+	guint statusbar_active:1; /* should we manage the statusbar messages ourselves? */
+	guint hide_deleted:1;
+	guint list_active:1;	/* we actually showing the list? */
 };
 
 struct _EMFolderViewClass {
 	GtkVBoxClass parent_class;
-	
+
 	/* behaviour definition */
-	int update_message_style:1;
-	
+	guint update_message_style:1;
+
 	/* if used as a control, used to activate/deactivate custom menu's */
 	void (*activate)(EMFolderView *, struct _BonoboUIComponent *uic, int state);
 
@@ -131,13 +133,14 @@ EMPopupTargetSelect *em_folder_view_get_popup_target(EMFolderView *emfv, EMPopup
 int em_folder_view_mark_selected(EMFolderView *emfv, guint32 mask, guint32 set);
 int em_folder_view_open_selected(EMFolderView *emfv);
 
-int em_folder_view_print(EMFolderView *emfv, int preview);
+int em_folder_view_print(EMFolderView *emfv, GtkPrintOperationAction action);
 
 /* this could be on message-list */
 guint32 em_folder_view_disable_mask(EMFolderView *emfv);
 
 void em_folder_view_set_statusbar(EMFolderView *emfv, gboolean statusbar);
 void em_folder_view_set_hide_deleted(EMFolderView *emfv, gboolean status);
+void em_folder_view_setup_view_instance (EMFolderView *emfv);
 
 #ifdef __cplusplus
 }
