@@ -54,6 +54,8 @@
 #include <gtk/gtkoptionmenu.h>
 #include <gtk/gtkmenuitem.h>
 
+#include "libedataserverui/e-cell-renderer-color.h"
+
 #include "e-util/e-util-private.h"
 
 #include "mail-config.h"
@@ -182,57 +184,254 @@ citation_color_set (GtkColorButton *color_button, EMMailerPrefs *prefs)
 		spec, NULL);
 }
 
-static void
-labels_changed (EMMailerPrefs *prefs)
-{
-	GSList *l, *n, *list = NULL;
-	const char *cstring;
-	char *string;
-	int i;
+enum {
+	LABEL_LIST_COLUMN_COLOR,
+	LABEL_LIST_COLUMN_TAG,
+	LABEL_LIST_COLUMN_NAME
+};
 
-	for (i = 4; i >= 0; i--) {
+static void
+label_name_edited_cb (GtkCellRendererText *cell, gchar *path_string, gchar *new_text, EMMailerPrefs *prefs)
+{
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (prefs->label_tree));
+
+	gtk_tree_model_get_iter_from_string (model, &iter, path_string);
+
+	g_strstrip (new_text);
+
+	/* allow only nonempty texts and always strip spaces there */
+	if (new_text && *new_text) {
+		gchar *tag = NULL;
+
+		gtk_tree_model_get (model, &iter, LABEL_LIST_COLUMN_TAG, &tag, -1);
+
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, LABEL_LIST_COLUMN_NAME, new_text, -1);
+		mail_config_set_label_name (tag, new_text);
+
+		g_free (tag);
+	}
+}
+
+static void
+label_sensitive_buttons (EMMailerPrefs *prefs)
+{
+	gboolean can_remove = FALSE, have_selected = FALSE, locked;
+
+	g_return_if_fail (prefs);
+
+	/* it's not sensitive if it's locked for updates */
+	locked = !GTK_WIDGET_IS_SENSITIVE (prefs->label_tree);
+
+	if (!locked) {
+		GtkTreeSelection *selection;
+		GtkTreeModel *model;
+		GtkTreeIter iter;
+
+		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (prefs->label_tree));
+		if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+			gchar *tag = NULL;
+
+			gtk_tree_model_get (model, &iter, LABEL_LIST_COLUMN_TAG, &tag, -1);
+
+			can_remove = tag && !mail_config_is_system_label (tag);
+			have_selected = TRUE;
+
+			g_free (tag);
+		}
+	}
+
+	gtk_widget_set_sensitive (prefs->label_remove, !locked && can_remove);
+	gtk_widget_set_sensitive (prefs->label_color,  !locked && have_selected);
+}
+
+static void
+label_tree_cursor_changed (GtkWidget *widget, gpointer user_data)
+{
+	label_sensitive_buttons (user_data);
+}
+
+static GtkListStore *
+init_label_tree (GtkWidget *label_tree, EMMailerPrefs *prefs, gboolean locked)
+{
+	GtkListStore *store;
+	GSList *labels;
+	GtkCellRenderer *renderer;
+	gint col;
+
+	g_return_val_if_fail (label_tree != NULL, NULL);
+	g_return_val_if_fail (prefs != NULL, NULL);
+
+	store = gtk_list_store_new (3, GDK_TYPE_COLOR, G_TYPE_STRING, G_TYPE_STRING);
+	gtk_tree_view_set_model (GTK_TREE_VIEW (label_tree), GTK_TREE_MODEL (store));
+
+	renderer = e_cell_renderer_color_new ();
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (label_tree), -1, _("Color"), renderer, "color", LABEL_LIST_COLUMN_COLOR, NULL);
+
+	renderer = gtk_cell_renderer_text_new ();
+	col = gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (label_tree), -1, _("Tag"), renderer, "text", LABEL_LIST_COLUMN_TAG, NULL);
+	g_object_set (G_OBJECT (renderer), "editable", FALSE, NULL);
+	gtk_tree_view_column_set_visible (gtk_tree_view_get_column (GTK_TREE_VIEW (label_tree), col - 1), FALSE);
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (label_tree), -1, _("Name"), renderer, "text", LABEL_LIST_COLUMN_NAME, NULL);
+	g_object_set (G_OBJECT (renderer), "editable", !locked, NULL);
+
+	if (!locked) {
+		g_signal_connect (renderer, "edited", G_CALLBACK (label_name_edited_cb), prefs);
+		g_signal_connect (label_tree, "cursor-changed", G_CALLBACK (label_tree_cursor_changed), prefs);
+	}
+
+	for (labels = mail_config_get_labels (); labels; labels = labels->next) {
 		GdkColor color;
+		GtkTreeIter iter;
+		MailConfigLabel *label = labels->data;
 
-		cstring = gtk_entry_get_text (prefs->labels[i].name);
-		gtk_color_button_get_color (prefs->labels[i].color, &color);
-		string = g_strdup_printf ("%s:#%04x%04x%04x", cstring,
-			color.red, color.green, color.blue);
-		list = g_slist_prepend (list, string);
+		if (label->colour)
+			gdk_color_parse (label->colour, &color);
+
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (
+			store, &iter,
+			LABEL_LIST_COLUMN_COLOR, label->colour ? &color : NULL,
+			LABEL_LIST_COLUMN_NAME, label->name,
+			LABEL_LIST_COLUMN_TAG, label->tag,
+			-1);
 	}
 
-	gconf_client_set_list (prefs->gconf, "/apps/evolution/mail/labels", GCONF_VALUE_STRING, list, NULL);
+	label_sensitive_buttons (prefs);
 
-	l = list;
-	while (l != NULL) {
-		n = l->next;
-		g_free (l->data);
-		g_slist_free_1 (l);
-		l = n;
+	return store;
+}
+
+static void
+label_add_cb (GtkWidget *widget, gpointer user_data)
+{
+	EMMailerPrefs *prefs = user_data;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	char *tag, *name;
+	int tagid;
+	GtkTreePath *path;
+	GdkColor gray;
+
+	g_return_if_fail (prefs != NULL);
+
+	tag = mail_config_get_next_label_tag (&tagid);
+
+	if (!tag)
+		return;
+
+	memset (&gray, 0xCD, sizeof (GdkColor));
+	name = g_strdup_printf ("%s %d", _("Label"), tagid);
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (prefs->label_tree));
+
+	if (mail_config_add_label (tag, name, &gray)) {
+		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+			LABEL_LIST_COLUMN_COLOR, &gray,
+			LABEL_LIST_COLUMN_NAME, name,
+			LABEL_LIST_COLUMN_TAG, tag,
+			-1);
+
+		path = gtk_tree_model_get_path (model, &iter);
+		if (path) {
+			GtkTreeViewColumn *focus_col = gtk_tree_view_get_column (GTK_TREE_VIEW (prefs->label_tree), LABEL_LIST_COLUMN_NAME);
+
+			gtk_tree_view_set_cursor (GTK_TREE_VIEW (prefs->label_tree), path, focus_col, TRUE);
+			gtk_tree_view_row_activated (GTK_TREE_VIEW (prefs->label_tree), path, focus_col);
+			gtk_tree_path_free (path);
+		}
+	}
+
+	g_free (tag);
+	g_free (name);
+}
+
+static void
+label_remove_cb (GtkWidget *widget, gpointer user_data)
+{
+	EMMailerPrefs *prefs = user_data;
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+
+	g_return_if_fail (prefs != NULL);
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (prefs->label_tree));
+	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+		gchar *tag = NULL;
+
+		gtk_tree_model_get (model, &iter, LABEL_LIST_COLUMN_TAG, &tag, -1);
+
+		if (tag && !mail_config_is_system_label (tag)) {
+			gint children;
+
+			gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
+			mail_config_remove_label (tag);
+
+			children = gtk_tree_model_iter_n_children (model, NULL);
+			if (children > 0) {
+				GtkTreePath *path;
+
+				if (!gtk_list_store_iter_is_valid (GTK_LIST_STORE (model), &iter))
+					gtk_tree_model_iter_nth_child (model, &iter, NULL, children - 1);
+
+				path = gtk_tree_model_get_path (model, &iter);
+				if (path) {
+					GtkTreeViewColumn *focus_col = gtk_tree_view_get_column (GTK_TREE_VIEW (prefs->label_tree), LABEL_LIST_COLUMN_NAME);
+
+					gtk_tree_view_set_cursor (GTK_TREE_VIEW (prefs->label_tree), path, focus_col, FALSE);
+					gtk_tree_view_row_activated (GTK_TREE_VIEW (prefs->label_tree), path, focus_col);
+					gtk_tree_path_free (path);
+				}
+			}
+		}
+
+		g_free (tag);
 	}
 }
 
 static void
-label_color_set (GtkWidget *widget, EMMailerPrefs *prefs)
+label_color_cb (GtkWidget *widget, gpointer user_data)
 {
-	labels_changed (prefs);
-}
+	EMMailerPrefs *prefs = user_data;
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
 
-static void
-label_entry_changed (GtkEntry *entry, EMMailerPrefs *prefs)
-{
-	labels_changed (prefs);
-}
+	g_return_if_fail (prefs != NULL);
 
-static void
-restore_labels_clicked (GtkWidget *widget, gpointer user_data)
-{
-	EMMailerPrefs *prefs = (EMMailerPrefs *) user_data;
-	int i;
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (prefs->label_tree));
+	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+		GtkWidget *dialog;
+		GdkColor *color = NULL, color2;
 
-	for (i = 0; i < 5; i++) {
-		gtk_entry_set_text (prefs->labels[i].name, _(label_defaults[i].name));
-		color_button_set_color (prefs->labels[i].color, label_defaults[i].colour);
-		atk_object_set_name(gtk_widget_get_accessible((GtkWidget *)prefs->labels[i].color), _(label_defaults[i].name));
+		gtk_tree_model_get (model, &iter, LABEL_LIST_COLUMN_COLOR, &color, -1);
+
+		dialog = gtk_color_selection_dialog_new (_("Select color for label..."));
+		gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel), color);
+
+		if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
+			gtk_color_selection_get_current_color (GTK_COLOR_SELECTION (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel), &color2);
+
+			if (!color || memcmp (color, &color2, sizeof(GdkColor)) != 0) {
+				gchar *tag = NULL;
+
+				gtk_tree_model_get (model, &iter, LABEL_LIST_COLUMN_TAG, &tag, -1);
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, LABEL_LIST_COLUMN_COLOR, &color2, -1);
+
+				mail_config_set_label_color (tag, &color2);
+
+				g_free (tag);
+			}
+		}
+
+		gtk_widget_destroy (dialog);
+		if (color)
+			gdk_color_free (color);
 	}
 }
 
@@ -702,36 +901,6 @@ http_images_changed (GtkWidget *widget, EMMailerPrefs *prefs)
 }
 
 
-static void
-notify_type_changed (GtkWidget *widget, EMMailerPrefs *prefs)
-{
-	int type;
-
-	if (gtk_toggle_button_get_active (prefs->notify_not))
-		type = MAIL_CONFIG_NOTIFY_NOT;
-	else if (gtk_toggle_button_get_active (prefs->notify_beep))
-		type = MAIL_CONFIG_NOTIFY_BEEP;
-	else
-		type = MAIL_CONFIG_NOTIFY_PLAY_SOUND;
-
-	if (type == MAIL_CONFIG_NOTIFY_PLAY_SOUND)
-                gtk_widget_set_sensitive ((GtkWidget *) prefs->notify_sound_file, TRUE);
-	else
-	        gtk_widget_set_sensitive ((GtkWidget *) prefs->notify_sound_file, FALSE);
-
-	gconf_client_set_int (prefs->gconf, "/apps/evolution/mail/notify/type", type, NULL);
-}
-
-static void
-notify_sound_changed (GtkWidget *widget, EMMailerPrefs *prefs)
-{
-	const char *filename;
-
-	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (prefs->notify_sound_file));
-	/* When we startup the file name will be NULL*/
-	gconf_client_set_string (prefs->gconf, "/apps/evolution/mail/notify/sound", filename ? filename : "", NULL);
-}
-
 static GtkWidget *
 emmp_widget_glade(EConfig *ec, EConfigItem *item, struct _GtkWidget *parent, struct _GtkWidget *old, void *data)
 {
@@ -872,7 +1041,7 @@ create_combo_text_widget (void) {
 static void
 em_mailer_prefs_construct (EMMailerPrefs *prefs)
 {
-	GSList *list, *header_config_list, *header_add_list, *p;
+	GSList *header_config_list, *header_add_list, *p;
 	GHashTable *default_header_hash;
 	GtkWidget *toplevel;
 	GtkTreeSelection *selection;
@@ -927,6 +1096,11 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs)
 			    "/apps/evolution/mail/display/force_message_limit",
 			    G_CALLBACK (toggle_button_toggled));
 
+	prefs->magic_spacebar = GTK_TOGGLE_BUTTON (glade_xml_get_widget (gui, "magic_spacebar_checkbox"));
+	toggle_button_init (prefs, prefs->magic_spacebar, FALSE,
+			    "/apps/evolution/mail/display/magic_spacebar",
+			    G_CALLBACK (toggle_button_toggled));
+
 	prefs->mlimit_count = GTK_SPIN_BUTTON (glade_xml_get_widget (gui, "mlimit_spin"));
 	spin_button_init (prefs, prefs->mlimit_count,
 			  "/apps/evolution/mail/display/message_text_part_limit",
@@ -968,38 +1142,6 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs)
 			    "/apps/evolution/mail/prompts/expunge",
 			    G_CALLBACK (toggle_button_toggled));
 
-	/* New Mail Notification */
-	locked = !gconf_client_key_is_writable (prefs->gconf, "/apps/evolution/mail/notify/type", NULL);
-
-	val = gconf_client_get_int (prefs->gconf, "/apps/evolution/mail/notify/type", NULL);
-	prefs->notify_not = GTK_TOGGLE_BUTTON (glade_xml_get_widget (gui, "radNotifyNot"));
-	gtk_toggle_button_set_active (prefs->notify_not, val == MAIL_CONFIG_NOTIFY_NOT);
-	g_signal_connect (prefs->notify_not, "toggled", G_CALLBACK (notify_type_changed), prefs);
-	if (locked)
-		gtk_widget_set_sensitive ((GtkWidget *) prefs->notify_not, FALSE);
-
-	prefs->notify_beep = GTK_TOGGLE_BUTTON (glade_xml_get_widget (gui, "radNotifyBeep"));
-	prefs->notify_sound_file = GTK_FILE_CHOOSER_BUTTON (glade_xml_get_widget (gui, "fileNotifyPlaySoundButton"));
-	gtk_toggle_button_set_active (prefs->notify_beep, val == MAIL_CONFIG_NOTIFY_BEEP);
-	g_signal_connect (prefs->notify_beep, "toggled", G_CALLBACK (notify_type_changed), prefs);
-	if (locked)
-		gtk_widget_set_sensitive ((GtkWidget *) prefs->notify_beep, FALSE);
-
-	prefs->notify_play_sound = GTK_TOGGLE_BUTTON (glade_xml_get_widget (gui, "radNotifyPlaySound"));
-	gtk_toggle_button_set_active (prefs->notify_play_sound, val == MAIL_CONFIG_NOTIFY_PLAY_SOUND);
-	g_signal_connect (prefs->notify_play_sound, "toggled", G_CALLBACK (notify_type_changed), prefs);
-	if (locked)
-		gtk_widget_set_sensitive ((GtkWidget *) prefs->notify_play_sound, FALSE);
-
-	buf = gconf_client_get_string (prefs->gconf, "/apps/evolution/mail/notify/sound", NULL);
-	if (buf && *buf)
-		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (prefs->notify_sound_file), buf);
-	g_signal_connect (GTK_FILE_CHOOSER_BUTTON (prefs->notify_sound_file), "selection-changed",
-			  G_CALLBACK (notify_sound_changed), prefs);
-	if (val != MAIL_CONFIG_NOTIFY_PLAY_SOUND)
-		gtk_widget_set_sensitive ((GtkWidget *) prefs->notify_sound_file, FALSE);
-	g_free (buf);
-
 	/* Mail  Fonts */
 	font = gconf_client_get_string (prefs->gconf, "/apps/evolution/mail/display/fonts/monospace", NULL);
 	prefs->font_fixed = GTK_FONT_BUTTON (glade_xml_get_widget (gui, "FontFixed"));
@@ -1062,39 +1204,24 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs)
 
 	/* Labels... */
 	locked = !gconf_client_key_is_writable (prefs->gconf, "/apps/evolution/mail/labels", NULL);
-	i = 0;
-	list = mail_config_get_labels ();
-	while (list != NULL && i < 5) {
-		MailConfigLabel *label;
-		char *widget_name;
-		label = list->data;
+	prefs->label_add    = glade_xml_get_widget (gui, "labelAdd");
+	prefs->label_remove = glade_xml_get_widget (gui, "labelRemove");
+	prefs->label_color  = glade_xml_get_widget (gui, "labelColor");
+	prefs->label_tree   = glade_xml_get_widget (gui, "labelTree");
 
-		widget_name = g_strdup_printf ("txtLabel%d", i);
-		prefs->labels[i].name = GTK_ENTRY (glade_xml_get_widget (gui, widget_name));
-		gtk_widget_set_sensitive ((GtkWidget *) prefs->labels[i].name, !locked);
-		g_free (widget_name);
+	gtk_widget_set_sensitive (prefs->label_add, !locked);
+	gtk_widget_set_sensitive (prefs->label_remove, !locked);
+	gtk_widget_set_sensitive (prefs->label_color, !locked);
+	gtk_widget_set_sensitive (prefs->label_tree, !locked);
 
-		widget_name = g_strdup_printf ("colorLabel%d", i);
-		prefs->labels[i].color = GTK_COLOR_BUTTON (glade_xml_get_widget (gui, widget_name));
-		gtk_widget_set_sensitive ((GtkWidget *) prefs->labels[i].color, !locked);
-		g_free (widget_name);
+	prefs->label_list_store = init_label_tree (prefs->label_tree, prefs, locked);
 
-		gtk_entry_set_text (prefs->labels[i].name, label->name);
-		g_signal_connect (prefs->labels[i].name, "changed", G_CALLBACK (label_entry_changed), prefs);
-
-		color_button_set_color (prefs->labels[i].color, label->colour);
-		g_signal_connect (prefs->labels[i].color, "color-set", G_CALLBACK (label_color_set), prefs);
-
-		atk_object_set_name(gtk_widget_get_accessible((GtkWidget *)prefs->labels[i].color), label->name);
-
-		i++;
-		list = list->next;
+	if (!locked) {
+		g_signal_connect (G_OBJECT (prefs->label_add), "clicked", G_CALLBACK (label_add_cb), prefs);
+		g_signal_connect (G_OBJECT (prefs->label_remove), "clicked", G_CALLBACK (label_remove_cb), prefs);
+		g_signal_connect (G_OBJECT (prefs->label_color), "clicked", G_CALLBACK (label_color_cb), prefs);
 	}
 
-	prefs->restore_labels = GTK_BUTTON (glade_xml_get_widget (gui, "cmdRestoreLabels"));
-	gtk_widget_set_sensitive ((GtkWidget *) prefs->restore_labels, !locked);
-	g_signal_connect (prefs->restore_labels, "clicked", G_CALLBACK (restore_labels_clicked), prefs);
-
 	/* headers */
 	locked = !gconf_client_key_is_writable (prefs->gconf, "/apps/evolution/mail/display/headers", NULL);
 
