@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -36,7 +36,7 @@ GtkWidget *mail_send_receive(void);
 void mail_receive_uri(const char *uri, int keep);
 void mail_send (void);
 /* setup auto receive stuff */
-void mail_autoreceive_setup(void);
+void mail_autoreceive_init(void);
 
 #ifdef __cplusplus
 }
