@@ -639,7 +639,7 @@ static const char *authors[] = {
 	NULL
 };
 
-static const char *documentors[] = { 
+static const char *documentors[] = {
 	"Aaron Weber",
 	"Binika Preet",
 	"Dan Winship",
@@ -679,18 +679,20 @@ command_about (BonoboUIComponent *uih,
 		NULL);
 }
 
-#if 0
-/* Unused */
 static void
-command_help_faq (BonoboUIComponent *uih,
+command_open_faq (BonoboUIComponent *uih,
 		  EShellWindow *window,
-		  const char *path)
+ 		  const char *path)
 {
-	/* FIXME Show when we have a faq */
-	/* FIXME use the error */
-	gnome_url_show ("http://gnome.org/projects/evolution/faq.shtml", NULL);	
-}
-#endif
+ 	GError *error = NULL;
+
+	gnome_url_show ("http://www.go-evolution.org/FAQ", &error);
+	if (error != NULL) {
+		e_notice (NULL, GTK_MESSAGE_ERROR,
+				_("Error opening the FAQ webpage."));
+ 		g_error_free (error);
+ 	}
+ }
 
 static void
 command_quick_reference (BonoboUIComponent *uih,
@@ -780,7 +782,7 @@ command_forget_passwords (BonoboUIComponent *ui_component,
 			  void *data,
 			  const char *path)
 {
-	if (e_error_run (NULL, "shell:forget-passwords", NULL) == GTK_RESPONSE_OK) 
+	if (e_error_run (NULL, "shell:forget-passwords", NULL) == GTK_RESPONSE_OK)
 		e_passwords_forget_passwords();
 }
 
@@ -837,6 +839,7 @@ static BonoboUIVerb tools_verbs[] = {
 
 static BonoboUIVerb help_verbs [] = {
 	BONOBO_UI_VERB ("QuickReference", (BonoboUIVerbFn) command_quick_reference),
+	BONOBO_UI_VERB ("HelpOpenFAQ", (BonoboUIVerbFn) command_open_faq),
 	BONOBO_UI_VERB ("HelpSubmitBug", (BonoboUIVerbFn) command_submit_bug),
 	BONOBO_UI_VERB ("HelpAbout", (BonoboUIVerbFn) command_about),
 
@@ -853,7 +856,7 @@ static EPixmap pixmaps [] = {
 	E_PIXMAP ("/menu/File/FileClose", "window-close", E_ICON_SIZE_MENU),
 	E_PIXMAP ("/menu/File/FileExit", "application-exit", E_ICON_SIZE_MENU),
 	E_PIXMAP ("/menu/Edit/Settings", "preferences-desktop", E_ICON_SIZE_MENU),
-	
+
 	E_PIXMAP_END
 };
 
@@ -994,7 +997,7 @@ view_buttons_hide_item_toggled_handler (BonoboUIComponent           *ui_componen
 	gboolean is_visible;
 
 	sidebar = e_shell_window_peek_sidebar (shell_window);
-	
+
 	is_visible = state[0] == '0';
 
 	e_sidebar_set_show_buttons (sidebar, is_visible);
@@ -1026,7 +1029,7 @@ view_statusbar_item_toggled_handler (BonoboUIComponent           *ui_component,
 	gboolean is_visible;
 	GConfClient *gconf_client;
 
-	is_visible = state[0] == '1';	
+	is_visible = state[0] == '1';
 	if(is_visible)
 		gtk_widget_show (status_bar);
 	else
@@ -1047,7 +1050,7 @@ view_sidebar_item_toggled_handler (BonoboUIComponent           *ui_component,
 	gboolean is_visible;
 	GConfClient *gconf_client;
 
-	is_visible = state[0] == '1';	
+	is_visible = state[0] == '1';
 	if(is_visible)
 		gtk_widget_show (side_bar);
 	else
